@@ -1,11 +1,16 @@
 use super::*;
-use awita_windows_bindings::Windows::Win32::{
-    Foundation::*,
-    Globalization::*,
-    Graphics::Gdi::*,
-    UI::{Controls::*, HiDpi::*, KeyboardAndMouseInput::*, Shell::*, WindowsAndMessaging::*},
-};
 use std::rc::Rc;
+use windows::Win32::{
+    Foundation::*,
+    Graphics::Gdi::*,
+    UI::{
+        Controls::*,
+        HiDpi::*,
+        Input::{Ime::*, KeyboardAndMouse::*},
+        Shell::*,
+        WindowsAndMessaging::*,
+    },
+};
 
 fn context() -> Rc<Context> {
     CONTEXT.with(|ctx| ctx.borrow().as_ref().unwrap().clone())
